@@ -41,12 +41,14 @@ from jsw_nx.packages.parse_cookie import parse_cookie
 from jsw_nx.packages.qs import qs
 from jsw_nx.packages.tmpl import tmpl
 from jsw_nx.packages.deep_each import deep_each
+from jsw_nx.packages.filesize import filesize
 from jsw_nx.packages.get_domain import get_domain
 from jsw_nx.packages.html2text import html2text
 from jsw_nx.packages.is_process_alive import is_process_alive
 from jsw_nx.packages.md5 import md5
 from jsw_nx.packages.notify import notify
 from jsw_nx.packages.replace_dict_all import replace_dict_all
+from jsw_nx.packages.sample import sample
 from jsw_nx.packages.sleep_random import sleep_random
 from jsw_nx.packages.uniq import uniq
 from jsw_nx.packages.uniq_in_order import uniq_in_order
